==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_auv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_auv
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'aus articles futurs solament (gran d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'aus articles totes sens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a totes los articles, fòra aqueles que lor forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires se devon abonar en donar lor adreiça e-mail avans de poder mandar de contribucions).',
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (las
 contribucions apareisson en public mas se los administrators
 las an validadas).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat amb abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar los messatges tot regde
 (las contribucions apareisson tanlèu mandadas, los administrators las pòdon
 suprimir puèi).',

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Podètz pas mai accedir vèrs aqueles forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> vòstre messatge deu téner aumens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> vòstre títol deu téner aumens tres caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aqueste forum es moderat a priòri: vòstra contribucion pareisserá pas qu’après qu’un administrator dau sit l’aja validada.', # MODIF
	'forum_lien_hyper' => '<b>Liam ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu : mandar au sit',
	'forum_message_trop_long' => 'Vòstre messatge es tròp long. La lonjor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mas per lo forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(se vòstre messatge se referís a un article publicat per lo web, o a una pagina que baile mai d’informacions, volhatz marcar çai sos lo títol de la pagina e son adreiça URL.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ que fai seguda a vòstre article.', # MODIF
	'forum_qui_etes_vous' => '<b>Quau sètz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt de vòstre messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquela chausida',
	'forum_voir_avant' => 'Veire lo messatge avans de lo mandar', # MODIF
	'forum_votre_email' => 'Vòstra adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Vòstre nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Per participar a
  aquel forum, d’en primèir vos chau registrar. Mercés
  de marcar çai sos l’identificant personau qu’avètz recebut.
 Se sètz pas registrat/ada, avètz de',
	'forum_vous_inscrire' => 'vos inscriure ',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Segut dau forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Sègre/gerir los forums',
	'icone_supprimer_message' => 'Suprimir aquel messatge',
	'icone_valider_message' => 'Validar aquel messatge',
	'info_activer_forum_public' => '<i>Per activar los forums publics, volhatz chausir lor mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion daus forums publics. Los forums publics poirán èsser autorizats au cas per cas sobre los articles; serán proïbits sobre las rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Enviament daus forums aus autors daus articles',
	'info_fonctionnement_forum' => 'Foncionament dau forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>segut daus forums</i> es un espleit de gestion dau vòstre sit (mas z-es pas un espaci per discutir o per redigir). Aficha totas las contribucions dau forum public d’aquel article e vos permet de gerir aquelas contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'z-es',
	'info_liens_syndiques_7' => 'en apèita de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit daus forums publics',
	'info_option_email' => 'Quand un vesitaire dau sit manda un messatge nuòu au forum
 associat a un article, se’n pòt avisar los autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Ges de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum daus administrators',
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum daus administrators',

	// L
	'lien_reponse_article' => 'Responsa a l’article',
	'lien_reponse_breve_2' => 'Responsa a la brèva',
	'lien_reponse_rubrique' => 'Responsa a la rubrica',
	'lien_reponse_site_reference' => 'Responsa au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sens tèxt',

	// R
	'repondre_message' => 'Respondre a aquel messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat daus administrators',
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Segut daus forums',
	'titre_page_forum_suivi' => 'Segut daus forums',
];

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_oc_auv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=oc_auv
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'aus articles futurs solament (gran d’accion sus la basa de donadas).',
	'bouton_radio_articles_tous' => 'aus articles totes sens excepcion',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'a totes los articles, fòra aqueles que lor forum es desactivat.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrament obligatòri (los utilizaires se devon abonar en donar lor adreiça e-mail avans de poder mandar de contribucions).', # MODIF
	'bouton_radio_moderation_priori' => 'Moderacion a priòri (las
 contribucions apareisson en public mas se los administrators
 las an validadas).', # MODIF
	'bouton_radio_modere_abonnement' => 'moderat amb abonament',
	'bouton_radio_modere_posteriori' => 'moderat a posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderat a priòri', # MODIF
	'bouton_radio_publication_immediate' => 'Publicar los messatges tot regde
 (las contribucions apareisson tanlèu mandadas, los administrators las pòdon
 suprimir puèi).', # MODIF

	// F
	'form_pet_message_commentaire' => 'Un messatge, una remarca?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Podètz pas mai accedir vèrs aqueles forums.',
	'forum_attention_dix_caracteres' => '<b>Atencion!</b> vòstre messatge deu téner aumens dètz caractèrs.',
	'forum_attention_trois_caracteres' => '<b>Atencion!</b> vòstre títol deu téner aumens tres caractèrs.',
	'forum_avez_selectionne' => 'Avètz seleccionat:',
	'forum_cliquer_retour' => 'Clicatz <a href=\'@retour_forum@\'>aicí</a> per contunhar.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Aqueste forum es moderat a priòri: vòstra contribucion pareisserá pas qu’après qu’un administrator dau sit l’aja validada.', # MODIF
	'forum_lien_hyper' => '<b>Liam ipertèxt</b> (opcionau)', # MODIF
	'forum_message_definitif' => 'Messatge definitiu : mandar au sit',
	'forum_message_trop_long' => 'Vòstre messatge es tròp long. La lonjor maximala es de 20 000 caractèrs.', # MODIF
	'forum_ne_repondez_pas' => 'Respondatz pas a aquel e-mail mas per lo forum a l’adreiça seguenta: ', # MODIF
	'forum_page_url' => '(se vòstre messatge se referís a un article publicat per lo web, o a una pagina que baile mai d’informacions, volhatz marcar çai sos lo títol de la pagina e son adreiça URL.)',
	'forum_poste_par' => 'Messatge poste@parauteur@ que fai seguda a vòstre article.', # MODIF
	'forum_qui_etes_vous' => '<b>Quau sètz?</b> (opcionau)', # MODIF
	'forum_texte' => 'Tèxt de vòstre messatge:', # MODIF
	'forum_titre' => 'Títol:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validar aquela chausida',
	'forum_voir_avant' => 'Veire lo messatge avans de lo mandar', # MODIF
	'forum_votre_email' => 'Vòstra adreiça e-mail:', # MODIF
	'forum_votre_nom' => 'Vòstre nom (o pseudonim):', # MODIF
	'forum_vous_enregistrer' => 'Per participar a
  aquel forum, d’en primèir vos chau registrar. Mercés
  de marcar çai sos l’identificant personau qu’avètz recebut.
 Se sètz pas registrat/ada, avètz de',
	'forum_vous_inscrire' => 'vos inscriure ',

	// I
	'icone_poster_message' => 'Postar un messatge',
	'icone_suivi_forum' => 'Segut dau forum public: @nb_forums@ contribucion(s)',
	'icone_suivi_forums' => 'Sègre/gerir los forums',
	'icone_supprimer_message' => 'Suprimir aquel messatge',
	'icone_valider_message' => 'Validar aquel messatge',
	'info_activer_forum_public' => '<i>Per activar los forums publics, volhatz chausir lor mòde de moderacion predefinit:</i>', # MODIF
	'info_appliquer_choix_moderation' => 'Aplicar aquela chausida de moderacion:',
	'info_desactiver_forum_public' => 'Desactivar l’utilizacion daus forums publics. Los forums publics poirán èsser autorizats au cas per cas sobre los articles; serán proïbits sobre las rubricas, brèvas, etc.',
	'info_envoi_forum' => 'Enviament daus forums aus autors daus articles', # MODIF
	'info_fonctionnement_forum' => 'Foncionament dau forum:',
	'info_gauche_suivi_forum_2' => 'La pagina de <i>segut daus forums</i> es un espleit de gestion dau vòstre sit (mas z-es pas un espaci per discutir o per redigir). Aficha totas las contribucions dau forum public d’aquel article e vos permet de gerir aquelas contribucions.', # MODIF
	'info_liens_syndiques_3' => 'forums',
	'info_liens_syndiques_4' => 'son',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'z-es',
	'info_liens_syndiques_7' => 'en apèita de validacion',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mòde de foncionament predefinit daus forums publics',
	'info_option_email' => 'Quand un vesitaire dau sit manda un messatge nuòu au forum
 associat a un article, se’n pòt avisar los autors
 de l’article per e-mail. Desiratz d’utilizar aquela opcion?', # MODIF
	'info_pas_de_forum' => 'Ges de forum',
	'item_activer_forum_administrateur' => 'Activar lo forum daus administrators', # MODIF
	'item_desactiver_forum_administrateur' => 'Desactivar lo forum daus administrators', # MODIF

	// L
	'lien_reponse_article' => 'Responsa a l’article',
	'lien_reponse_breve_2' => 'Responsa a la brèva',
	'lien_reponse_rubrique' => 'Responsa a la rubrica',
	'lien_reponse_site_reference' => 'Responsa au sit referenciat:', # MODIF

	// O
	'onglet_messages_internes' => 'Messatges intèrnes',
	'onglet_messages_publics' => 'Messatges publics',
	'onglet_messages_vide' => 'Messatges sens tèxt',

	// R
	'repondre_message' => 'Respondre a aquel messatge',

	// T
	'titre_cadre_forum_administrateur' => 'Forum privat daus administrators', # MODIF
	'titre_cadre_forum_interne' => 'Forum intèrne',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Segut daus forums',
	'titre_page_forum_suivi' => 'Segut daus forums',
];
